# TaskState


## Enum

* `Cancelled` (value: `-2`)

* `Error` (value: `-1`)

* `Pending` (value: `0`)

* `Rescheduled` (value: `1`)

* `Running` (value: `2`)

* `Completed` (value: `3`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


